# VisaComment

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**author** | [**UserProject**](UserProject.md) |  | [optional] 
**author_id** | **int** | This is the userproject_id. This field is only used if the call is made from an App | [optional] 
**visa_id** | **str** |  | [optional] [readonly] 
**content** | **str** |  | [optional] 
**reply_to_comment_id** | **int** |  | [optional] 
**created_at** | **datetime** |  | [optional] [readonly] 
**updated_at** | **datetime** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


